==> kubernetes-model-admissionregistration-5.0.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authentication/TokenReviewSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authentication;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class TokenReviewSpecFluentImpl<A extends TokenReviewSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements TokenReviewSpecFluent<A> {

    private List<String> audiences = new ArrayList<String>();
    private String token;

    public TokenReviewSpecFluentImpl() { 
    }


    public TokenReviewSpecFluentImpl(TokenReviewSpec instance) { 
        this.withAudiences(instance.getAudiences()); 
        this.withToken(instance.getToken()); 
    }


    public A addToAudiences(int index,String item) {
        if (this.audiences == null) {this.audiences = new ArrayList<String>();}
        this.audiences.add(index, item);
        return (A)this;
    }

    public A setToAudiences(int index,String item) {
        if (this.audiences == null) {this.audiences = new ArrayList<String>();}
        this.audiences.set(index, item); return (A)this;
    }

    public A addToAudiences(String... items) {
        if (this.audiences == null) {this.audiences = new ArrayList<String>();}
        for (String item : items) {this.audiences.add(item);} return (A)this;
    }

    public A addAllToAudiences(Collection<String> items) {
        if (this.audiences == null) {this.audiences = new ArrayList<String>();}
        for (String item : items) {this.audiences.add(item);} return (A)this;
    }

    public A removeFromAudiences(String... items) {
        for (String item : items) {if (this.audiences!= null){ this.audiences.remove(item);}} return (A)this;
    }

    public A removeAllFromAudiences(Collection<String> items) {
        for (String item : items) {if (this.audiences!= null){ this.audiences.remove(item);}} return (A)this;
    }

    public List<String> getAudiences() {
        return this.audiences;
    }

    public String getAudience(int index) {
        return this.audiences.get(index);
    }

    public String getFirstAudience() {
        return this.audiences.get(0);
    }

    public String getLastAudience() {
        return this.audiences.get(audiences.size() - 1);
    }

    public String getMatchingAudience(Predicate<String> predicate) {
        for (String item: audiences) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingAudience(Predicate<String> predicate) {
        for (String item: audiences) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withAudiences(List<String> audiences) {
        if (this.audiences != null) { _visitables.get("audiences").removeAll(this.audiences);}
        if (audiences != null) {this.audiences = new ArrayList<String>(); for (String item : audiences){this.addToAudiences(item);}} else { this.audiences = null;} return (A) this;
    }

    public A withAudiences(String... audiences) {
        if (this.audiences != null) {this.audiences.clear();}
        if (audiences != null) {for (String item :audiences){ this.addToAudiences(item);}} return (A) this;
    }

    public Boolean hasAudiences() {
        return audiences != null && !audiences.isEmpty();
    }

    public A addNewAudience(String arg1) {
        return (A)addToAudiences(new String(arg1));
    }

    public A addNewAudience(StringBuilder arg1) {
        return (A)addToAudiences(new String(arg1));
    }

    public A addNewAudience(StringBuffer arg1) {
        return (A)addToAudiences(new String(arg1));
    }

    public String getToken() {
        return this.token;
    }

    public A withToken(String token) {
        this.token=token; return (A) this;
    }

    public Boolean hasToken() {
        return this.token != null;
    }

    public A withNewToken(String arg1) {
        return (A)withToken(new String(arg1));
    }

    public A withNewToken(StringBuilder arg1) {
        return (A)withToken(new String(arg1));
    }

    public A withNewToken(StringBuffer arg1) {
        return (A)withToken(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        TokenReviewSpecFluentImpl that = (TokenReviewSpecFluentImpl) o;
        if (audiences != null ? !audiences.equals(that.audiences) :that.audiences != null) return false;
        if (token != null ? !token.equals(that.token) :that.token != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(audiences,  token,  super.hashCode());
    }

}

==> kubernetes-model-admissionregistration-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authentication/TokenReviewSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authentication;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class TokenReviewSpecFluentImpl<A extends TokenReviewSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements TokenReviewSpecFluent<A> {

    private List<String> audiences = new ArrayList<String>();
    private String token;

    public TokenReviewSpecFluentImpl() {
    }

    public TokenReviewSpecFluentImpl(TokenReviewSpec instance) {
        this.withAudiences(instance.getAudiences()); 
        this.withToken(instance.getToken()); 
    }

    public A addToAudiences(int index,String item) {
        if (this.audiences == null) {this.audiences = new ArrayList<String>();}
        this.audiences.add(index, item);
        return (A)this;
    }

    public A setToAudiences(int index,String item) {
        if (this.audiences == null) {this.audiences = new ArrayList<String>();}
        this.audiences.set(index, item); return (A)this;
    }

    public A addToAudiences(String... items) {
        if (this.audiences == null) {this.audiences = new ArrayList<String>();}
        for (String item : items) {this.audiences.add(item);} return (A)this;
    }

    public A addAllToAudiences(Collection<String> items) {
        if (this.audiences == null) {this.audiences = new ArrayList<String>();}
        for (String item : items) {this.audiences.add(item);} return (A)this;
    }

    public A removeFromAudiences(String... items) {
        for (String item : items) {if (this.audiences!= null){ this.audiences.remove(item);}} return (A)this;
    }

    public A removeAllFromAudiences(Collection<String> items) {
        for (String item : items) {if (this.audiences!= null){ this.audiences.remove(item);}} return (A)this;
    }

    public List<String> getAudiences() {
        return this.audiences;
    }

    public String getAudience(int index) {
        return this.audiences.get(index);
    }

    public String getFirstAudience() {
        return this.audiences.get(0);
    }

    public String getLastAudience() {
        return this.audiences.get(audiences.size() - 1);
    }

    public String getMatchingAudience(Predicate<String> predicate) {
        for (String item: audiences) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingAudience(Predicate<String> predicate) {
        for (String item: audiences) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withAudiences(List<String> audiences) {
        if (this.audiences != null) { _visitables.get("audiences").removeAll(this.audiences);}
        if (audiences != null) {this.audiences = new ArrayList<String>(); for (String item : audiences){this.addToAudiences(item);}} else { this.audiences = null;} return (A) this;
    }

    public A withAudiences(String... audiences) {
        if (this.audiences != null) {this.audiences.clear();}
        if (audiences != null) {for (String item :audiences){ this.addToAudiences(item);}} return (A) this;
    }

    public Boolean hasAudiences() {
        return audiences != null && !audiences.isEmpty();
    }

    public A addNewAudience(StringBuilder arg1) {
        return (A)addToAudiences(new String(arg1));
    }

    public A addNewAudience(int[] arg1,int arg2,int arg3) {
        return (A)addToAudiences(new String(arg1, arg2, arg3));
    }

    public A addNewAudience(char[] arg1) {
        return (A)addToAudiences(new String(arg1));
    }

    public A addNewAudience(StringBuffer arg1) {
        return (A)addToAudiences(new String(arg1));
    }

    public A addNewAudience(byte[] arg1,int arg2) {
        return (A)addToAudiences(new String(arg1, arg2));
    }

    public A addNewAudience(byte[] arg1) {
        return (A)addToAudiences(new String(arg1));
    }

    public A addNewAudience(char[] arg1,int arg2,int arg3) {
        return (A)addToAudiences(new String(arg1, arg2, arg3));
    }

    public A addNewAudience(byte[] arg1,int arg2,int arg3) {
        return (A)addToAudiences(new String(arg1, arg2, arg3));
    }

    public A addNewAudience(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)addToAudiences(new String(arg1, arg2, arg3, arg4));
    }

    public A addNewAudience(String arg1) {
        return (A)addToAudiences(new String(arg1));
    }

    public String getToken() {
        return this.token;
    }

    public A withToken(String token) {
        this.token=token; return (A) this;
    }

    public Boolean hasToken() {
        return this.token != null;
    }

    public A withNewToken(StringBuilder arg1) {
        return (A)withToken(new String(arg1));
    }

    public A withNewToken(int[] arg1,int arg2,int arg3) {
        return (A)withToken(new String(arg1, arg2, arg3));
    }

    public A withNewToken(char[] arg1) {
        return (A)withToken(new String(arg1));
    }

    public A withNewToken(StringBuffer arg1) {
        return (A)withToken(new String(arg1));
    }

    public A withNewToken(byte[] arg1,int arg2) {
        return (A)withToken(new String(arg1, arg2));
    }

    public A withNewToken(byte[] arg1) {
        return (A)withToken(new String(arg1));
    }

    public A withNewToken(char[] arg1,int arg2,int arg3) {
        return (A)withToken(new String(arg1, arg2, arg3));
    }

    public A withNewToken(byte[] arg1,int arg2,int arg3) {
        return (A)withToken(new String(arg1, arg2, arg3));
    }

    public A withNewToken(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withToken(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewToken(String arg1) {
        return (A)withToken(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        TokenReviewSpecFluentImpl that = (TokenReviewSpecFluentImpl) o;
        if (audiences != null ? !audiences.equals(that.audiences) :that.audiences != null) return false;
        if (token != null ? !token.equals(that.token) :that.token != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(audiences,  token,  super.hashCode());
    }

}
